@@ -1,5 +1,5 @@
 from .color_picker import *
 from .default import *
 from .elements import *
-from .hough_circles import *
+from draugr.opencv_utilities.windows.deprecated.hough_circles import *
 from .image import *
