@@ -8,7 +8,7 @@ __all__ = ["ExtensionEnum", "match_return_code"]
 ESC_CHAR = chr(27)
 
 
-def match_return_code(ret_val, chars: Iterable[str] = ("q", ESC_CHAR)):
+def match_return_code(ret_val, chars: Iterable[str] = ("q", ESC_CHAR)) -> bool:
     """
 
     :param ret_val:
@@ -18,7 +18,9 @@ def match_return_code(ret_val, chars: Iterable[str] = ("q", ESC_CHAR)):
     :return:
     :rtype:
     """
-    return any(ret_val & 0xFF == ord(c) for c in chars)
+    if ret_val:
+        return any(ret_val & 0xFF == ord(c) for c in chars)
+    return False
 
 
 class ExtensionEnum(Enum):
