@@ -6,3 +6,6 @@ from .architecture import *
 from .distributional import *
 from .mlp import *
 from .mlp_variants import *
+from .vae import *
+from .experimental import *
+from .recurrent import *
