@@ -14,7 +14,8 @@ __all__ = ["DisplaySampler"]
 
 class DisplaySampler(object):
     """
-    # A class that will downsample the data and recompute when zoomed."""
+    # A class that will downsample the data and recompute when zoomed.
+    """
 
     def __init__(self, x_data, y_data, verbose: bool = False):
         self._y_data = y_data
@@ -24,7 +25,16 @@ class DisplaySampler(object):
         self.verbose = verbose
 
     def downsample(self, xstart, xend):
-        """description"""
+        """
+        Downsample the data to the given limits
+
+        :param xstart:
+        :type xstart:
+        :param xend:
+        :type xend:
+        :return:
+        :rtype:
+        """
         mask = (self._x_data > xstart) & (
             self._x_data < xend
         )  # get the points in the view range
