@@ -15,7 +15,7 @@ __all__ = ["MockWriter"]
 
 
 class MockWriter(Writer):
-    """ """
+    """description"""
 
     def _close(self, exc_type=None, exc_val=None, exc_tb=None) -> None:
         pass
